@@ -90,20 +90,38 @@ class RequestMixIn:
         headers : Dict[str, str]
             Mapping of header names to header values
         """
-        if www_claim := headers.get('ig-set-www-claim'): self.state.www_claim = www_claim
-        if authorization := headers.get('ig-set-authorization'): self.state.authorization = authorization
-        if user_id := headers.get('ig-set-ig-u-ds-user-id'): self.state.user_id = user_id
-        if direct_region_hint := headers.get(
-            'ig-set-ig-u-direct_region_hint'): self.state.direct_region_hint = direct_region_hint
-        if shbid := headers.get('ig-set-ig-u-shbid'): self.state.shbid = shbid
-        if shbts := headers.get('ig-set-ig-u-shbts'): self.state.shbts = shbts
-        if target := headers.get('ig-set-ig-u-target'): self.state.target = target
-        if rur := headers.get('ig-set-ig-u-rur'): self.state.rur = rur
-        if mid := headers.get('ig-set-x-mid'): self.state.mid = mid
-        if public_api_key_id := headers.get(
-            'ig-set-password-encryption-key-id'): self.state.public_api_key_id = public_api_key_id
-        if public_api_key := headers.get('ig-set-password-encryption-pub-key'): self.state.public_api_key = \
-            public_api_key; self._encrypt_password()
+        www_claim = headers.get('ig-set-www-claim')
+        if www_claim is not None: self.state.www_claim = www_claim
+
+        authorization = headers.get('ig-set-authorization')
+        if authorization is not None: self.state.authorization = authorization
+
+        user_id = headers.get('ig-set-ig-u-ds-user-id')
+        if user_id is not None: self.state.user_id = user_id
+
+        direct_region_hint = headers.get('ig-set-ig-u-direct_region_hint')
+        if direct_region_hint is not None: self.state.direct_region_hint = direct_region_hint
+
+        shbid = headers.get('ig-set-ig-u-shbid')
+        if shbid is not None: self.state.shbid = shbid
+
+        shbts = headers.get('ig-set-ig-u-shbts')
+        if shbts is not None: self.state.shbts = shbts
+
+        target = headers.get('ig-set-ig-u-target')
+        if target is not None: self.state.target = target
+
+        rur = headers.get('ig-set-ig-u-rur')
+        if rur is not None: self.state.rur = rur
+
+        mid = headers.get('ig-set-x-mid')
+        if mid is not None: self.state.mid = mid
+
+        public_api_key_id = headers.get('ig-set-password-encryption-key-id')
+        if public_api_key_id is not None: self.state.public_api_key_id = public_api_key_id
+
+        public_api_key = headers.get('ig-set-password-encryption-pub-key')
+        if public_api_key is not None: self.state.public_api_key = public_api_key; self._encrypt_password()
 
     def _request(self, endpoint: str, method: Method, query: dict = None, data: dict = None, headers: Dict[str, str]
     = None, default_headers: bool = None, signed: bool = None) -> requests.Response:
